/*
 * Module code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDesigner.h"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpainter.sip"
#include <qpainter.h>
#line 32 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 35 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 41 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 509 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 44 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 47 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 471 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 50 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 460 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 570 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 619 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 592 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 608 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 675 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 302 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 438 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 77 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 425 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 80 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 412 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 83 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 398 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 86 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 384 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 89 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 363 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 92 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 253 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 95 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 205 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 98 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 101 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 52 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintengine.sip"
#include <qpaintengine.h>
#line 104 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpaintdevice.sip"
#include <qpaintdevice.h>
#line 107 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 110 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 113 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 116 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformeditor.sip"
#include <abstractformeditor.h>
#line 119 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 122 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindow.sip"
#include <abstractformwindow.h>
#line 125 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qiodevice.sip"
#include <qiodevice.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qdir.sip"
#include <qdir.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindow.sip"
#include <abstractformwindow.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindowcursor.sip"
#include <abstractformwindowcursor.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformwindowmanager.sip"
#include <abstractformwindowmanager.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qactiongroup.sip"
#include <qactiongroup.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qicon.sip"
#include <qicon.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 164 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/customwidget.sip"
#include <QtDesigner>
#line 167 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/extension.sip"
#include <extension.h>
#line 170 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 173 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 176 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/abstractformbuilder.sip"
#include <abstractformbuilder.h>
#line 179 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/default_extensionfactory.sip"
#include <default_extensionfactory.h>
#line 182 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/formbuilder.sip"
#include <formbuilder.h>
#line 185 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/qextensionmanager.sip"
#include <qextensionmanager.h>
#line 188 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtDesigner[] = {
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'u', 'r', 's', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'M', 'o', 'v', 'e', 'O', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'A', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'u', 'r', 's', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'M', 'o', 'v', 'e', 'M', 'o', 'd', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 'F', 'l', 'a', 'g', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'u', 's', 't', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'P', 'y', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'u', 's', 't', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 'C', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'u', 's', 't', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', '*', '>', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', ':', ':', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'u', 'r', 's', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'O', 'b', 'j', 'e', 'c', 't', 'I', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'P', 'y', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'S', 'h', 'e', 'e', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'E', 'd', 'i', 't', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'S', 'h', 'e', 'e', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'P', 'y', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'M', 'e', 'm', 'b', 'e', 'r', 'S', 'h', 'e', 'e', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'D', 'i', 'a', 'l', 'o', 'g', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'A', 'c', 't', 'i', 'o', 'n', 'E', 'd', 'i', 't', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'u', 's', 't', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'M', 'e', 'm', 'b', 'e', 'r', 'S', 'h', 'e', 'e', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'P', 'y', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'P', 'y', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'u', 's', 't', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 'P', 'l', 'u', 'g', 'i', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'E', 'd', 'i', 't', 'o', 'r', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'P', 'y', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'T', 'a', 's', 'k', 'M', 'e', 'n', 'u', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'W', 'i', 'd', 'g', 'e', 't', 'B', 'o', 'x', 'I', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 0,
    'Q', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 'T', 'a', 's', 'k', 'M', 'e', 'n', 'u', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 'P', 'a', 't', 'h', 's', 0,
    'f', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'S', 'e', 't', 't', 'i', 'n', 'g', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'S', 't', 'y', 'l', 'e', 'd', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 'A', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 'P', 'a', 't', 'h', 's', 0,
    'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'L', 'a', 'y', 'o', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'S', 'p', 'l', 'i', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'b', 'o', 'u', 't', 'T', 'o', 'U', 'n', 'm', 'a', 'n', 'a', 'g', 'e', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'F', 'o', 'r', 'm', 'B', 'u', 'i', 'l', 'd', 'e', 'r', 0,
    'S', 'i', 'm', 'p', 'l', 'i', 'f', 'y', 'L', 'a', 'y', 'o', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'L', 'a', 'y', 'o', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'S', 'i', 'm', 'p', 'l', 'i', 'f', 'y', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'e', 'm', 'i', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'i', 'n', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    'S', 'p', 'l', 'i', 't', 'V', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'a', 'm', 'e', 0,
    'i', 'n', 'h', 'e', 'r', 'i', 't', 'e', 'd', 'F', 'r', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'p', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', 'E', 'd', 'i', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'r', 'e', 's', 'e', 't', 'W', 'i', 'd', 'g', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'W', 'i', 'd', 'g', 'e', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    's', 'e', 't', 'W', 'o', 'r', 'k', 'i', 'n', 'g', 'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    'f', 'o', 'c', 'u', 's', 'N', 'e', 'x', 't', 'P', 'r', 'e', 'v', 'C', 'h', 'i', 'l', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 'I', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 0,
    'B', 'r', 'e', 'a', 'k', 'L', 'a', 'y', 'o', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'F', 'a', 'c', 't', 'o', 'r', 'y', 0,
    'Q', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'f', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'f', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'h', 'a', 's', 'H', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'L', 'a', 'y', 'o', 'u', 't', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'i', 'x', 'm', 'a', 'p', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'E', 'd', 'i', 't', 'o', 'r', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'A', 'd', 'j', 'u', 's', 't', 'S', 'i', 'z', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'F', 'o', 'r', 'm', 'L', 'a', 'y', 'o', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'G', 'r', 'i', 'd', 'L', 'a', 'y', 'o', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'D', 'e', 's', 'i', 'g', 'n', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'F', 'o', 'r', 'm', 'L', 'a', 'y', 'o', 'u', 't', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'c', 'l', 'e', 'a', 'r', 'P', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 's', 0,
    'c', 'l', 'o', 's', 'e', 'A', 'l', 'l', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 's', 0,
    'c', 'o', 'n', 't', 'e', 'x', 't', 'M', 'e', 'n', 'u', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 'p', 'u', 't', 'M', 'e', 't', 'h', 'o', 'd', 'Q', 'u', 'e', 'r', 'y', 0,
    'i', 's', 'W', 'i', 'd', 'g', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'y', 'o', 'u', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    's', 'e', 't', 'M', 'a', 'i', 'n', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'G', 'r', 'o', 'u', 'p', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'h', 'o', 'w', 'P', 'l', 'u', 'g', 'i', 'n', 'D', 'i', 'a', 'l', 'o', 'g', 0,
    'w', 'o', 'r', 'k', 'i', 'n', 'g', 'D', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'A', 'l', 'l', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'T', 'a', 'b', 'O', 'r', 'd', 'e', 'r', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'a', 'd', 'd', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'E', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'd', 'e', 'c', 'l', 'a', 'r', 'e', 'd', 'I', 'n', 'C', 'l', 'a', 's', 's', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'A', 'd', 'd', 'e', 'd', 0,
    'f', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'i', 'n', 'i', 'm', 'u', 'm', 'S', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'I', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'o', 'n', 'E', 'd', 'i', 't', 'o', 'r', 0,
    's', 'e', 't', 'C', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'I', 'n', 'c', 'l', 'u', 'd', 'e', 'H', 'i', 'n', 't', 's', 0,
    'w', 'i', 'd', 'g', 'e', 't', 'U', 'n', 'm', 'a', 'n', 'a', 'g', 'e', 'd', 0,
    'D', 'e', 'f', 'a', 'u', 'l', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'd', 'r', 'a', 'g', 'E', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'd', 'r', 'a', 'g', 'L', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'i', 'n', 'd', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'F', 'o', 'r', 'W', 'i', 'd', 't', 'h', 0,
    'l', 'a', 'y', 'o', 'u', 't', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'N', 'a', 'm', 'e', 's', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 'T', 'y', 'p', 'e', 's', 0,
    'p', 'i', 'x', 'm', 'a', 'p', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'E', 'd', 'i', 't', 'o', 'r', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'W', 'i', 'd', 'g', 'e', 't', 0,
    's', 'e', 't', 'E', 'x', 'p', 'o', 'r', 't', 'M', 'a', 'c', 'r', 'o', 0,
    's', 'e', 't', 'M', 'e', 'm', 'b', 'e', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    'u', 'n', 'm', 'a', 'n', 'a', 'g', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'u', 'n', 'm', 'a', 'n', 'a', 'g', 'e', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'a', 'd', 'd', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'a', 'd', 'd', 'P', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 0,
    'c', 'h', 'e', 'c', 'k', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'c', 'u', 's', 't', 'o', 'm', 'W', 'i', 'd', 'g', 'e', 't', 's', 0,
    'd', 'r', 'a', 'g', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 'M', 'e', 's', 's', 'a', 'g', 'e', 's', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'r', 'm', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 0,
    'i', 's', 'I', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 'd', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 'y', 'o', 'u', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'm', 'a', 'i', 'n', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 0,
    'o', 'b', 'j', 'e', 'c', 't', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'G', 'r', 'o', 'u', 'p', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'F', 'i', 'l', 'e', 's', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    's', 'e', 't', 'P', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 0,
    's', 'h', 'a', 'r', 'e', 'd', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'w', 'i', 'd', 'g', 'e', 't', 'M', 'a', 'n', 'a', 'g', 'e', 'd', 0,
    'w', 'i', 'd', 'g', 'e', 't', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'D', 'e', 'l', 'e', 't', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'F', 'o', 'r', 'm', 'B', 'u', 'i', 'l', 'd', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'E', 'd', 'i', 't', 'o', 'r', 0,
    'c', 'a', 'n', 'A', 'd', 'd', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'c', 'o', 'd', 'e', 'T', 'e', 'm', 'p', 'l', 'a', 't', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'I', 'n', 'd', 'e', 'x', 0,
    'e', 'r', 'r', 'o', 'r', 'M', 'e', 's', 's', 'a', 'g', 'e', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'h', 'a', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 'n', 'c', 'l', 'u', 'd', 'e', 'H', 'i', 'n', 't', 's', 0,
    'i', 'n', 's', 'e', 'r', 't', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'm', 'o', 'v', 'e', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'a', 'm', 'e', 0,
    's', 'e', 'l', 'e', 'c', 't', 'W', 'i', 'd', 'g', 'e', 't', 0,
    's', 'e', 't', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    's', 'e', 't', 'W', 'i', 'd', 'g', 'e', 't', 'B', 'o', 'x', 0,
    'E', 'd', 'i', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'G', 'r', 'i', 'd', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'L', 'o', 'w', 'e', 'r', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'P', 'a', 's', 't', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'R', 'a', 'i', 's', 'e', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'b', 's', 'o', 'l', 'u', 't', 'e', 'D', 'i', 'r', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'a', 'c', 't', 'i', 'o', 'n', 'G', 'r', 'o', 'u', 'p', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'x', 'p', 'o', 'r', 't', 'M', 'a', 'c', 'r', 'o', 0,
    'i', 'n', 'c', 'l', 'u', 'd', 'e', 'F', 'i', 'l', 'e', 0,
    'i', 'n', 'i', 't', 'P', 'a', 'i', 'n', 't', 'e', 'r', 0,
    'i', 's', 'A', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 0,
    'i', 's', 'C', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 0,
    'm', 'e', 'm', 'b', 'e', 'r', 'G', 'r', 'o', 'u', 'p', 0,
    'n', 'a', 't', 'i', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'p', 'l', 'u', 'g', 'i', 'n', 'P', 'a', 't', 'h', 's', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'F', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    's', 'e', 't', 'F', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    's', 'h', 'o', 'w', 'P', 'r', 'e', 'v', 'i', 'e', 'w', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    't', 'a', 's', 'k', 'A', 'c', 't', 'i', 'o', 'n', 's', 0,
    'w', 'i', 'd', 'g', 'e', 't', 'C', 'o', 'u', 'n', 't', 0,
    'C', 'o', 'p', 'y', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'K', 'e', 'e', 'p', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'M', 'o', 'v', 'e', 'A', 'n', 'c', 'h', 'o', 'r', 0,
    'R', 'e', 'd', 'o', 'A', 'c', 't', 'i', 'o', 'n', 0,
    'U', 'n', 'd', 'o', 'A', 'c', 't', 'i', 'o', 'n', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'l', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'n', 't', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'r', 'r', 'o', 'r', 'C', 'o', 'u', 'n', 't', 0,
    'f', 'o', 'r', 'm', 'W', 'i', 'n', 'd', 'o', 'w', 0,
    'h', 'a', 's', 'F', 'e', 'a', 't', 'u', 'r', 'e', 0,
    'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 'z', 'e', 0,
    'i', 's', 'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    'l', 'e', 'a', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'e', 'm', 'b', 'e', 'r', 'N', 'a', 'm', 'e', 0,
    'p', 'a', 'i', 'n', 't', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'm', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'C', 'u', 't', 'A', 'c', 't', 'i', 'o', 'n', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', 0,
    'a', 'd', 'd', 'W', 'i', 'd', 'g', 'e', 't', 0,
    'c', 'a', 'n', 'R', 'e', 'm', 'o', 'v', 'e', 0,
    'd', 'r', 'o', 'p', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'd', 0,
    'i', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'A', 'u', 't', 'h', 'o', 'r', 0,
    's', 'e', 't', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    's', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    'w', 'h', 'a', 't', 's', 'T', 'h', 'i', 's', 0,
    'w', 'i', 'd', 'g', 'e', 't', 'B', 'o', 'x', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 's', 0,
    'f', 'e', 'a', 't', 'u', 'r', 'e', 's', 0,
    'f', 'i', 'l', 'e', 'N', 'a', 'm', 'e', 0,
    'h', 'a', 's', 'R', 'e', 's', 'e', 't', 0,
    'i', 's', 'S', 'i', 'g', 'n', 'a', 'l', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 0,
    's', 'e', 't', 'D', 'i', 'r', 't', 'y', 0,
    's', 'i', 'z', 'e', 'H', 'i', 'n', 't', 0,
    't', 'o', 'p', 'L', 'e', 'v', 'e', 'l', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'l', 'e', 'n', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'c', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'm', 'm', 'e', 'n', 't', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 0,
    'd', 'e', 'v', 'T', 'y', 'p', 'e', 0,
    'i', 'n', 'd', 'e', 'x', 'O', 'f', 0,
    'i', 's', 'D', 'i', 'r', 't', 'y', 0,
    's', 'e', 't', 'G', 'r', 'i', 'd', 0,
    't', 'o', 'o', 'l', 'T', 'i', 'p', 0,
    'N', 'o', 'M', 'o', 'v', 'e', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'c', 't', 'i', 'o', 'n', 0,
    'a', 'u', 't', 'h', 'o', 'r', 0,
    'c', 'u', 'r', 's', 'o', 'r', 0,
    'd', 'o', 'm', 'X', 'm', 'l', 0,
    'i', 's', 'S', 'l', 'o', 't', 0,
    'm', 'e', 't', 'r', 'i', 'c', 0,
    'o', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 0,
    's', 'e', 'l', 'e', 'c', 't', 0,
    'u', 'p', 'd', 'a', 't', 'e', 0,
    'w', 'i', 'd', 'g', 'e', 't', 0,
    'R', 'i', 'g', 'h', 't', 0,
    'S', 't', 'a', 'r', 't', 0,
    'c', 'o', 'u', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'f', 'l', 'a', 'g', 's', 0,
    'g', 'r', 'o', 'u', 'p', 0,
    'r', 'e', 's', 'e', 't', 0,
    'D', 'o', 'w', 'n', 0,
    'L', 'e', 'f', 't', 0,
    'N', 'e', 'x', 't', 0,
    'P', 'r', 'e', 'v', 0,
    'c', 'o', 'r', 'e', 0,
    'g', 'r', 'i', 'd', 0,
    'i', 'c', 'o', 'n', 0,
    'l', 'o', 'a', 'd', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    's', 'a', 'v', 'e', 0,
    'E', 'n', 'd', 0,
    'i', 'i', 'd', 0,
    'U', 'p', 0,
};

::QAction* sipVH_QtDesigner_95(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QAction* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QAction, &sipRes);

    return sipRes;
}

QList< ::QAction*> sipVH_QtDesigner_94(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QList< ::QAction*> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0101QAction, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_93(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iN", a0, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

::QVariant sipVH_QtDesigner_92(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

QList< ::QByteArray> sipVH_QtDesigner_91(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    QList< ::QByteArray> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0100QByteArray, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_90(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, bool a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ib", a0, a1);
}

void sipVH_QtDesigner_89(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, const ::QString& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iN", a0, new ::QString(a1), sipType_QString, SIP_NULLPTR);
}

::QString sipVH_QtDesigner_88(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

int sipVH_QtDesigner_87(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_86(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAbstractExtensionFactory*a0, const ::QString& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QAbstractExtensionFactory, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);
}

::QObject* sipVH_QtDesigner_85(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, const ::QString& a1, ::QObject*a2)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DND", a0, sipType_QObject, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR, a2, sipType_QObject, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QObject, &sipRes);

    return sipRes;
}

::QObject* sipVH_QtDesigner_84(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, const ::QString& a1)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DN", a0, sipType_QObject, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

QList< ::QDesignerCustomWidgetInterface*> sipVH_QtDesigner_83(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    QList< ::QDesignerCustomWidgetInterface*> sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QList_0101QDesignerCustomWidgetInterface, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_82(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormEditorInterface*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDesignerFormEditorInterface, SIP_NULLPTR);
}

::QWidget* sipVH_QtDesigner_81(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0)
{
    ::QWidget* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QWidget, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QWidget, &sipRes);

    return sipRes;
}

::QIcon sipVH_QtDesigner_80(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QIcon sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QIcon, &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_79(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_78(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::QWidget*a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iD", a0, a1, sipType_QWidget, SIP_NULLPTR);
}

void sipVH_QtDesigner_77(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "i", a0);
}

void sipVH_QtDesigner_76(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QVariant& a1, bool a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NNb", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR, a2);
}

void sipVH_QtDesigner_75(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QObject, SIP_NULLPTR);
}

::QObject* sipVH_QtDesigner_74(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

::QActionGroup* sipVH_QtDesigner_73(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormWindowManagerInterface::ActionGroup a0)
{
    ::QActionGroup* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QDesignerFormWindowManagerInterface_ActionGroup);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QActionGroup, &sipRes);

    return sipRes;
}

::QAction* sipVH_QtDesigner_72(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormWindowManagerInterface::Action a0)
{
    ::QAction* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QDesignerFormWindowManagerInterface_Action);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QAction, &sipRes);

    return sipRes;
}

::QDesignerFormWindowInterface* sipVH_QtDesigner_71(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, ::Qt::WindowFlags a1)
{
    ::QDesignerFormWindowInterface* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DN", a0, sipType_QWidget, SIP_NULLPTR, new ::Qt::WindowFlags(a1), sipType_Qt_WindowFlags, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QDesignerFormWindowInterface, &sipRes);

    return sipRes;
}

::QDesignerFormWindowInterface* sipVH_QtDesigner_70(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QDesignerFormWindowInterface* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QDesignerFormWindowInterface, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_69(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, const ::QString& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QWidget, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);
}

void sipVH_QtDesigner_68(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, const ::QString& a1, const ::QVariant& a2)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DNN", a0, sipType_QWidget, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR, new ::QVariant(a2), sipType_QVariant, SIP_NULLPTR);
}

void sipVH_QtDesigner_67(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QVariant& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QVariant(a1), sipType_QVariant, SIP_NULLPTR);
}

::QWidget* sipVH_QtDesigner_66(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    ::QWidget* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QWidget, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_65(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, ::QDesignerFormWindowCursorInterface::MoveMode a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "iF", a0, a1, sipType_QDesignerFormWindowCursorInterface_MoveMode);
}

bool sipVH_QtDesigner_64(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormWindowCursorInterface::MoveOperation a0, ::QDesignerFormWindowCursorInterface::MoveMode a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "FF", a0, sipType_QDesignerFormWindowCursorInterface_MoveOperation, a1, sipType_QDesignerFormWindowCursorInterface_MoveMode);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QDesignerFormWindowInterface* sipVH_QtDesigner_63(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDesignerFormWindowInterface* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QDesignerFormWindowInterface, &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_62(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_61(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QPoint& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QPoint(a0), sipType_QPoint, SIP_NULLPTR);
}

void sipVH_QtDesigner_60(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0, bool a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "Db", a0, sipType_QWidget, SIP_NULLPTR, a1);
}

void sipVH_QtDesigner_59(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormWindowInterface::Feature a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QDesignerFormWindowInterface::Feature(a0), sipType_QDesignerFormWindowInterface_Feature, SIP_NULLPTR);
}

void sipVH_QtDesigner_58(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

bool sipVH_QtDesigner_57(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QWidget, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_56(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWidget*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWidget, SIP_NULLPTR);
}

::QWidget* sipVH_QtDesigner_55(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QWidget* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QWidget, &sipRes);

    return sipRes;
}

::QPoint sipVH_QtDesigner_54(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPoint sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QPoint, &sipRes);

    return sipRes;
}

::QDesignerFormWindowCursorInterface* sipVH_QtDesigner_53(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDesignerFormWindowCursorInterface* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QDesignerFormWindowCursorInterface, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_52(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QStringList& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QStringList(a0), sipType_QStringList, SIP_NULLPTR);
}

::QStringList sipVH_QtDesigner_51(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QStringList sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QStringList, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_50(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0, const ::QString& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QString(a0), sipType_QString, SIP_NULLPTR, new ::QString(a1), sipType_QString, SIP_NULLPTR);
}

void sipVH_QtDesigner_49(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QString*a0, ::QString*a1)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(H4H4)", sipType_QString, a0, sipType_QString, a1);
}

void sipVH_QtDesigner_48(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0, int a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "ii", a0, a1);
}

void sipVH_QtDesigner_47(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int*a0, int*a1)
{
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(ii)", a0, a1);
}

void sipVH_QtDesigner_46(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QString& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QString(a0), sipType_QString, SIP_NULLPTR);
}

bool sipVH_QtDesigner_45(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormWindowInterface::Feature a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::QDesignerFormWindowInterface::Feature(a0), sipType_QDesignerFormWindowInterface_Feature, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QDesignerFormWindowInterface::Feature sipVH_QtDesigner_44(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDesignerFormWindowInterface::Feature sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QDesignerFormWindowInterface_Feature, &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_43(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIODevice*a0, ::QString*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QIODevice, SIP_NULLPTR, a1, sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QDir sipVH_QtDesigner_42(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDir sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QDir, &sipRes);

    return sipRes;
}

::QString sipVH_QtDesigner_41(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_40(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIODevice*a0, ::QWidget*a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DD", a0, sipType_QIODevice, SIP_NULLPTR, a1, sipType_QWidget, SIP_NULLPTR);
}

::QWidget* sipVH_QtDesigner_39(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QIODevice*a0, ::QWidget*a1)
{
    ::QWidget* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QIODevice, SIP_NULLPTR, a1, sipType_QWidget, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QWidget, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_38(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDesignerFormWindowInterface*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDesignerFormWindowInterface, SIP_NULLPTR);
}

void sipVH_QtDesigner_37(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QAction*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QAction, SIP_NULLPTR);
}

::QDesignerFormEditorInterface* sipVH_QtDesigner_36(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QDesignerFormEditorInterface* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QDesignerFormEditorInterface, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_35(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

void sipVH_QtDesigner_34(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_33(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

bool sipVH_QtDesigner_32(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_31(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

int sipVH_QtDesigner_30(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintDevice::PaintDeviceMetric a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_QPaintDevice_PaintDeviceMetric);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

::QPaintEngine* sipVH_QtDesigner_29(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPaintEngine* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPaintEngine, &sipRes);

    return sipRes;
}

int sipVH_QtDesigner_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "b", a0);
}

::QSize sipVH_QtDesigner_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

int sipVH_QtDesigner_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, int a0)
{
    int sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "i", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "i", &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPaintEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPaintEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QCloseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QCloseEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QContextMenuEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QContextMenuEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QActionEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QActionEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragEnterEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragEnterEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragMoveEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDragLeaveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDragLeaveEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QDropEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QDropEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtDesigner_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QInputMethodEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QInputMethodEvent, SIP_NULLPTR);
}

::QVariant sipVH_QtDesigner_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt::InputMethodQuery a0)
{
    ::QVariant sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "F", a0, sipType_Qt_InputMethodQuery);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QVariant, &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, bool a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "b", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtDesigner_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QByteArray& a0, void*a1, long*a2)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NV", new ::QByteArray(a0), sipType_QByteArray, SIP_NULLPTR, a1);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "(bl)", &sipRes, a2);

    return sipRes;
}

::QPainter* sipVH_QtDesigner_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QPainter* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QPainter, &sipRes);

    return sipRes;
}

void sipVH_QtDesigner_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QPainter*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QPainter, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QExtensionManager(void **);}
static const sipTypeDef *sipSubClass_QExtensionManager(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtDesigner/qextensionmanager.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QPyDesignerCustomWidgetPlugin, &sipType_QPyDesignerCustomWidgetPlugin, -1, 1},
        {sipName_QExtensionFactory, &sipType_QExtensionFactory, -1, 2},
        {sipName_QPyDesignerMemberSheetExtension, &sipType_QPyDesignerMemberSheetExtension, -1, 3},
        {sipName_QDesignerFormEditorInterface, &sipType_QDesignerFormEditorInterface, -1, 4},
        {sipName_QDesignerWidgetBoxInterface, &sipType_QDesignerWidgetBoxInterface, -1, 5},
        {sipName_QDesignerFormWindowInterface, &sipType_QDesignerFormWindowInterface, -1, 6},
        {sipName_QDesignerActionEditorInterface, &sipType_QDesignerActionEditorInterface, -1, 7},
        {sipName_QPyDesignerContainerExtension, &sipType_QPyDesignerContainerExtension, -1, 8},
        {sipName_QDesignerPropertyEditorInterface, &sipType_QDesignerPropertyEditorInterface, -1, 9},
        {sipName_QDesignerFormWindowManagerInterface, &sipType_QDesignerFormWindowManagerInterface, -1, 10},
        {sipName_QPyDesignerTaskMenuExtension, &sipType_QPyDesignerTaskMenuExtension, -1, 11},
        {sipName_QPyDesignerPropertySheetExtension, &sipType_QPyDesignerPropertySheetExtension, -1, 12},
        {sipName_QDesignerObjectInspectorInterface, &sipType_QDesignerObjectInspectorInterface, -1, 13},
        {sipName_QPyDesignerCustomWidgetCollectionPlugin, &sipType_QPyDesignerCustomWidgetCollectionPlugin, -1, 14},
        {sipName_QExtensionManager, &sipType_QExtensionManager, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 1254 "/build/pyqt5/src/PyQt5-5.15.11/build/QtDesigner/sipQtDesignercmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDesignerFormWindowCursorInterface__MoveMode, SIP_NULLPTR, 0}, sipNameNr_MoveMode, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDesignerFormWindowCursorInterface__MoveOperation, SIP_NULLPTR, 0}, sipNameNr_MoveOperation, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDesignerFormWindowInterface__FeatureFlag, SIP_NULLPTR, 0}, sipNameNr_FeatureFlag, 11, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDesignerFormWindowManagerInterface__Action, SIP_NULLPTR, 0}, sipNameNr_Action, 14, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QDesignerFormWindowManagerInterface__ActionGroup, SIP_NULLPTR, 0}, sipNameNr_ActionGroup, 14, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtDesigner[] = {
    &sipTypeDef_QtDesigner_QAbstractExtensionFactory.ctd_base,
    &sipTypeDef_QtDesigner_QAbstractExtensionManager.ctd_base,
    &sipTypeDef_QtDesigner_QAbstractFormBuilder.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerActionEditorInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerContainerExtension.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerCustomWidgetCollectionInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerCustomWidgetInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerFormEditorInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerFormWindowCursorInterface.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_QtDesigner_QDesignerFormWindowInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerFormWindowInterface_Feature.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtDesigner_QDesignerFormWindowManagerInterface.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtDesigner_QDesignerMemberSheetExtension.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerObjectInspectorInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerPropertyEditorInterface.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerPropertySheetExtension.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerTaskMenuExtension.ctd_base,
    &sipTypeDef_QtDesigner_QDesignerWidgetBoxInterface.ctd_base,
    &sipTypeDef_QtDesigner_QExtensionFactory.ctd_base,
    &sipTypeDef_QtDesigner_QExtensionManager.ctd_base,
    &sipTypeDef_QtDesigner_QFormBuilder.ctd_base,
    &sipTypeDef_QtDesigner_QList_0101QDesignerCustomWidgetInterface.mtd_base,
    &sipTypeDef_QtDesigner_QPyDesignerContainerExtension.ctd_base,
    &sipTypeDef_QtDesigner_QPyDesignerCustomWidgetCollectionPlugin.ctd_base,
    &sipTypeDef_QtDesigner_QPyDesignerCustomWidgetPlugin.ctd_base,
    &sipTypeDef_QtDesigner_QPyDesignerMemberSheetExtension.ctd_base,
    &sipTypeDef_QtDesigner_QPyDesignerPropertySheetExtension.ctd_base,
    &sipTypeDef_QtDesigner_QPyDesignerTaskMenuExtension.ctd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtDesigner_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QDir"},
    {"QEvent"},
    {"QIODevice"},
    {"QList<QByteArray>"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QSize"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"QVariant"},
    {"Qt::InputMethodQuery"},
    {"Qt::WindowFlags"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDesigner_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtDesigner_QtGui[] = {
    {"QActionEvent"},
    {"QCloseEvent"},
    {"QContextMenuEvent"},
    {"QDragEnterEvent"},
    {"QDragLeaveEvent"},
    {"QDragMoveEvent"},
    {"QDropEvent"},
    {"QFocusEvent"},
    {"QHideEvent"},
    {"QIcon"},
    {"QInputMethodEvent"},
    {"QKeyEvent"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QPaintDevice"},
    {"QPaintDevice::PaintDeviceMetric"},
    {"QPaintEngine"},
    {"QPaintEvent"},
    {"QPainter"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QTabletEvent"},
    {"QWheelEvent"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtWidgets. */
sipImportedTypeDef sipImportedTypes_QtDesigner_QtWidgets[] = {
    {"QAction"},
    {"QActionGroup"},
    {"QList<QAction*>"},
    {"QWidget"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtDesigner_QtCore, sipImportedVirtErrorHandlers_QtDesigner_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtDesigner_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {"PyQt5.QtWidgets", sipImportedTypes_QtDesigner_QtWidgets, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QExtensionManager, {7, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtDesigner = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtDesigner,
    0,
    sipStrings_QtDesigner,
    importsTable,
    SIP_NULLPTR,
    33,
    sipExportedTypes_QtDesigner,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtDesigner;

sip_qt_metaobject_func sip_QtDesigner_qt_metaobject;
sip_qt_metacall_func sip_QtDesigner_qt_metacall;
sip_qt_metacast_func sip_QtDesigner_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtDesigner()
#else
PyMODINIT_FUNC PyInit_QtDesigner()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtDesigner",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtDesigner = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtDesigner == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtDesigner, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtDesigner_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtDesigner_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtDesigner_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtDesigner_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtDesigner, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
